Keen | Profile
Description: User profile overview

# Customer Relationship Management

New Order

### Profile

Reports
Luke Davids Angular Developer
Progress 78
luke@loop.com
lukemanson
45 Orders
246 Purchases
37 Reviews

### Latest Uploads

All FILES
Keeg Design Reqs
95 MB
S.E.R Agreement
805 MB
FlyMore Screenshot
4 MB
ST.11 Dacuments
Unknown
XML AOL Data Fetchin
4 MB
Drag files here
New Products

### Active Smartwatch

Beautifully designed watch that helps you track your fitness and diet – while keeping you motivated!
246
Purchases
37
Reviews
24 Nov, 2018
Date of Release
Preview Details

### DSLR Lens

Wide-angle, Quick Focus. Emphasis is on modern lenses for 35 mm film SLRs and for DSLRs with sensor sizes less than or equal to 35 mm.
142
Purchases
25
Reviews
24 Nov, 2018
Date of Release
Preview Details

### Polaroid Camera

Instant is back! Make photos fun again with the new range of Polaroid Instant Cameras with Vintage Effects and Built in Flash
3578
Purchases
457
Reviews
24 Nov, 2018
Date of Release
Preview Details
New Authors
Andy John
AngularJS Expert
sale@boatline.com
(+44) 345 345 4705
01 Sep, 2018
Joined Date
Message Profile
Patrick Smith
ReactJS Expert
patrick@boatline.com
(+44) 345 345 5574
01 Sep, 2018
Joined Date
Message Profile
Amanda Collin
Project Manager
amanda@boatline.com
(+44) 345 345 1247
01 Sep, 2018
Joined Date
Message Profile

### Work Progress

Pendings Tasks
78%
Completed Tasks
320 / 780
Tasks In Progress
45%
All Tasks
1200
Reports
40
Full Report
Pendings Tasks
78%
Completed Tasks
320 / 780
Tasks In Progress
45%
All Tasks
1200
Reports
40
Full Report

### Daily Salles

CSV
Chris Bent
SUV Themes Carp
$ 830
Ashley Stock
Merscedes Benz AMGww
$ 675
Jimmy Yesuku
All Nippon United Airlines
$ 194
Amanda West
Comboy Westem Limited
$ 65
Nick Holms
UILab Inc
$ 65

### Latest Tasks

Management meeting
09:30 AM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
NYCS internal discussion
03: 00 PM
Project Launch
11: 00 AM
Server maintenance
4: 30 PM
Export Navitare booking table
01:20 PM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
Replace datatables rows color
12:00 AM
NYCS internal discussion
03: 00 PM
Management meeting
09:30 AM
NYCS internal discussion
03: 00 PM
Replace datatables rows color
12:00 AM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
Export Navitare booking table
01:20 PM
Management meeting
09:30 AM

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!